<?php

defined( 'ABSPATH' ) || exit;

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if(!is_plugin_active( 'word-balloon-pro/word-balloon-pro.php' )):

	
	function word_balloon_add_menu() {

		require_once WORD_BALLOON_DIR . 'inc/admin-edit.php';

		$w_b_submenu_page = add_options_page(__('Setting Up Word Balloon','word-balloon'),'Word Balloon', 'administrator', 'word-balloon','word_balloon_admin_page');
		add_action( "admin_print_scripts-$w_b_submenu_page", 'word_balloon_only_edit_page_scripts' );

	}
	add_action( 'admin_menu', 'word_balloon_add_menu' );

	require_once WORD_BALLOON_DIR . 'inc/create_db.php';
	register_activation_hook( __FILE__, 'word_balloon_create_db' );


	add_action( 'plugins_loaded', 'word_balloon_update_db_check' );

endif;


function word_balloon_update_db_check() {

	if ( get_option( 'word_balloon_db_version' ) != WORD_BALLOON_VERSION ) {

		require_once WORD_BALLOON_DIR . 'inc/create_db.php';
		word_balloon_create_db();

	}

}


require_once WORD_BALLOON_DIR . 'inc/ajax_nonce.php';
add_action( 'wp_ajax_word_balloon_nonce_action_center', 'word_balloon_nonce_action_event' );



function word_balloon_only_edit_page_scripts() {




	
	wp_enqueue_media();

	
	wp_enqueue_script( 'jquery-ui-dialog' );
	wp_enqueue_style( 'wp-jquery-ui-dialog' );

	wp_enqueue_style('word_balloon_admin', WORD_BALLOON_URI . 'css/word_balloon_admin.min.css',array(),WORD_BALLOON_VERSION);
	wp_enqueue_style('word_balloon_edit', WORD_BALLOON_URI . 'css/word_balloon_edit.min.css',array('word_balloon_admin'),WORD_BALLOON_VERSION);
	wp_enqueue_style('word_balloon_font', WORD_BALLOON_URI . 'css/font/style.min.css',array(),WORD_BALLOON_VERSION);
	//add_action( 'wp_enqueue_scripts', 'word_balloon_translations_edit' );
	wp_register_script('word_balloon_edit', WORD_BALLOON_URI . 'js/word_balloon_edit.min.js',array( ),WORD_BALLOON_VERSION,true);
	wp_enqueue_script('word_balloon_edit');

	
	$translations = word_balloon_scriput_translations();
	wp_localize_script( 'word_balloon_edit', 'translations', $translations );
	
	wp_localize_script('word_balloon_edit','word_balloon_nonce_ajax_object',array(
		'ajax_url' => admin_url('admin-ajax.php'),
		'action' => 'word_balloon_nonce_action_center',
		'nonce' => wp_create_nonce("word_balloon_nonce_action_center"),
		
	));


}





function word_balloon_block_control_panel() {



	wp_enqueue_script('word_balloon_block_script', WORD_BALLOON_URI . 'js/word_balloon_block.js',array('wp-i18n', 'wp-element', 'wp-blocks', 'wp-components', 'wp-editor'));


	if ( function_exists( 'wp_set_script_translations' ) ) {
		
		wp_set_script_translations( 'word_balloon_block_script', 'word-balloon', WORD_BALLOON_DIR . 'languages' );

	} else if (function_exists('gutenberg_get_jed_locale_data')) {
		

		
		$locale  = gutenberg_get_jed_locale_data( 'word-balloon' );

		
		$content = 'wp.i18n.setLocaleData(' . json_encode( $locale ) . ', "word-balloon" );';

		
		wp_script_add_data( 'word_balloon_block_script', 'data', $content );
	}


	register_block_type( 'word-balloon/word-balloon-block', array(
		'editor_script' => 'word_balloon_block_script'	) );

	
	require_once WORD_BALLOON_DIR . 'inc/default_settings.php';

	$load_setting = word_balloon_default_settings('load_setting');

	
	foreach ($load_setting['disable_balloon'] as $key => $value) {
		if($value === 'true')unset($load_setting['type_balloon'][$key]);
	}

	$word_balloon_block_balloon = array();
	$i = 0;
	foreach ($load_setting['type_balloon'] as $balloon_type => $balloon_name) {

		if($balloon_type === 'rpg_1')$balloon_name = 'RPG Ⅰ';
		if($balloon_type === 'rpg_2')$balloon_name = 'RPG Ⅱ';
		if($balloon_type === 'rpg_3')$balloon_name = 'RPG Ⅲ';
		if($balloon_type === '8bit_2')$balloon_name = __( '8bit Ⅱ', 'word-balloon' );

		$word_balloon_block_balloon[$i] = array(
			'value' => $balloon_type,
			'label' => esc_html($balloon_name)
		);
		++$i;
	}

	
	foreach ($load_setting['disable_icon'] as $key => $value) {
		if($value === 'true')unset($load_setting['type_icon'][$key]);
	}

	$word_balloon_block_icon = array();

	$word_balloon_block_icon[0] = array(
		'value' => '',
		'label' => ''
	);
	$i = 1;
	foreach ($load_setting['type_icon'] as $icon_type => $icon_name) {
		$word_balloon_block_icon[$i] = array(
			'value' => $icon_type,
			'label' => esc_html($icon_name)
		);
		++$i;
	}

	$i = 0;
	$word_balloon_block_icon_position = array();
	foreach ($load_setting['icon_position'] as $icon_position => $icon_position_name) {
		$word_balloon_block_icon_position[$i] = array(
			'value' => $icon_position,
			'label' => esc_html($icon_position_name)
		);
		++$i;
	}

	
	foreach ($load_setting['disable_effect'] as $key => $value) {
		if($value === 'true')unset($load_setting['type_effect'][$key]);
	}

	$word_balloon_block_effect = array();

	$word_balloon_block_effect[0] = array(
		'value' => '',
		'label' => ''
	);
	$i = 1;
	foreach ($load_setting['type_effect'] as $effect_type => $effect_name) {
		$word_balloon_block_effect[$i] = array(
			'value' => $effect_type,
			'label' => esc_html($effect_name)
		);
		++$i;
	}


	
	foreach ($load_setting['disable_filter'] as $key => $value) {
		if($value === 'true')unset($load_setting['type_filter'][$key]);
	}

	$word_balloon_block_filter = array();

	$word_balloon_block_filter[0] = array(
		'value' => '',
		'label' => ''
	);
	$i = 1;
	foreach ($load_setting['type_filter'] as $filter_type => $filter_name) {
		$word_balloon_block_filter[$i] = array(
			'value' => $filter_type,
			'label' => esc_html($filter_name)
		);
		++$i;
	}


	
	global $wpdb;
	$table_name = $wpdb->prefix . 'word_balloon';
	$array = $wpdb->get_results("SELECT * FROM $table_name", 'ARRAY_A');
	$word_balloon_block_avatar = array();

	if(count(array_filter($array)) === 0 || $load_setting['keep_mystery_men'] === 'true'){
		$word_balloon_block_avatar[0] = array(
			'id' => 'mystery_men',
			'name' => __('Mystery Men','word-balloon'),
			'url' => WORD_BALLOON_URI . 'img/mystery_men.svg',
			'memo' => __('mysterious figure','word-balloon'),
		);
	}


	foreach($array as $key => $value){
		$word_balloon_block_avatar[$value['id']] = array(
			'id' => $value['id'],
			'name' => $value['name'],
			'url' => $value['url'],
			'memo' => $value['text'],
		);
	}


	$border_style = array(
		'none' => esc_html__( 'none', 'word-balloon' ),
		'solid' => esc_html__( 'Solid', 'word-balloon' ),
		'double' => esc_html__( 'Double', 'word-balloon' ),
		'groove' => esc_html__( 'Groove', 'word-balloon' ),
		'ridge' => esc_html__( 'Ridge', 'word-balloon' ),
		'inset' => esc_html__( 'Inset', 'word-balloon' ),
		'outset' => esc_html__( 'Outset', 'word-balloon' ),
		'dashed' => esc_html__( 'Dashed', 'word-balloon' ),
		'dotted' => esc_html__( 'Dotted', 'word-balloon' ),
	);
	$word_balloon_block_border_style = array();
	foreach($border_style as $key => $value){
		$word_balloon_block_border_style[] = array(
			'value' => $key,
			'label' => $value,
		);
	}

	$word_balloon_block_default_settings = array(
		'avatar_size' => $load_setting['avatar_size'],
		'avatar_position' => $load_setting['avatar_position'],
		'avatar_border_radius' => $load_setting['avatar_border_radius'],
		'avatar_border' => ($load_setting['avatar_border'] === 'true' ? true : false),
		'avatar_shadow' => ($load_setting['avatar_shadow'] === 'true' ? true : false),
		'avatar_hide' => ($load_setting['avatar_hide'] === 'true' ? true : false),
		'choice_balloon' => $load_setting['choice_balloon'],
		'balloon_shadow' => ($load_setting['balloon_shadow'] === 'true' ? true : false),
		'box_center' => ($load_setting['box_center'] === 'true' ? true : false),
		'balloon_full_width' => ($load_setting['balloon_full_width'] === 'true' ? true : false),
		'icon_size' => $load_setting['icon_size'],
		'name_position' => $load_setting['name_position'],
		'name_color' => $load_setting['name_color'],
		'status_color' => $load_setting['status_color'],
		'keep_mystery_men' => ($load_setting['keep_mystery_men'] === 'true' ? true : false),
		'word_balloon_url' => WORD_BALLOON_URI,
	);

	$word_balloon_block_template[] = array(
		'value' => '',
		'label' => __('Template','word-balloon')
	);
	foreach($load_setting['template'] as $key => $value){
		$word_balloon_block_template[] = array(
			'value' => $key,
			'label' => $value,
		);
	}


	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_avatar', $word_balloon_block_avatar );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_balloon', $word_balloon_block_balloon );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_icon', $word_balloon_block_icon );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_icon_position_data', $word_balloon_block_icon_position );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_effect', $word_balloon_block_effect );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_filter', $word_balloon_block_filter );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_border_style', $word_balloon_block_border_style );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_default_settings', $word_balloon_block_default_settings );
	wp_localize_script( 'word_balloon_block_script', 'word_balloon_block_template', $word_balloon_block_template );

	wp_enqueue_style('word_balloon_admin_block', WORD_BALLOON_URI . 'css/word_balloon_block.min.css',array('word_balloon_user_style'),WORD_BALLOON_VERSION);

}
add_action('enqueue_block_editor_assets', 'word_balloon_block_control_panel');



function word_balloon_custom_enqueue($hook_suffix) {
	
	if( 'post.php' == $hook_suffix || 'post-new.php' == $hook_suffix ) {

		
		require_once WORD_BALLOON_DIR . 'inc/default_settings.php';

		$load_setting = word_balloon_default_settings('load_setting');

		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'jquery-ui-dialog' );
		wp_enqueue_style( 'jquery-ui-dialog-min-css', includes_url().'css/jquery-ui-dialog.min.css' );
		
		wp_enqueue_script('word_balloon_balloon_custom_script', WORD_BALLOON_URI . 'js/word_balloon_balloon_custom.min.js',array('wp-color-picker','jquery'),WORD_BALLOON_VERSION,true);



		
		foreach ($load_setting['disable_balloon'] as $key => $value) {
			if($value === 'true')unset($load_setting['type_balloon'][$key]);
		}

		
		foreach ($load_setting['type_balloon'] as $balloon_type => $balloon_name) {
			wp_enqueue_style('word_balloon_skin_'.$balloon_type, WORD_BALLOON_URI . 'css/skin/word_balloon_'.$balloon_type.'.min.css',array('word_balloon_user_style'),WORD_BALLOON_VERSION);
			wp_enqueue_script('word_balloon_post_'.$balloon_type, WORD_BALLOON_URI . 'js/skin/word_balloon_skin_'.$balloon_type.'.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);
		}

		
		$judge = false;
		foreach ($load_setting['disable_effect'] as $key => $value) {
			if($value === 'true'){
				unset($load_setting['type_effect'][$key]);
			}else{
				$judge = true;
			}
		}

		if($judge){
			foreach ($load_setting['type_effect'] as $effect_type => $effect_name) {
				wp_enqueue_style('word_balloon_effect_'.$effect_type, WORD_BALLOON_URI . 'css/effect/word_balloon_'.$effect_type.'.min.css',array('word_balloon_user_style'),WORD_BALLOON_VERSION);
			}
			
			wp_enqueue_script('word_balloon_effect_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_effect.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);
		}


		
		$judge = false;
		foreach ($load_setting['disable_filter'] as $key => $value) {
			if($value === 'true'){
				unset($load_setting['type_filter'][$key]);
			}else{
				$judge = true;
			}
		}
		if($judge){
			foreach ($load_setting['type_filter'] as $filter_type => $filter_name) {
				wp_enqueue_style('word_balloon_filter_'.$filter_type, WORD_BALLOON_URI . 'css/filter/word_balloon_'.$filter_type.'.min.css',array('word_balloon_user_style'),WORD_BALLOON_VERSION);
			}
			
			wp_enqueue_script('word_balloon_filter_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_filter.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);
		}

		
		$judge = false;
		foreach ($load_setting['disable_icon'] as $key => $value) {
			if($value === 'true'){

			}else{
				$judge = true;
			}
		}
		if($judge){
			
			wp_enqueue_script('word_balloon_icon_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_icon.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);
			wp_enqueue_style('word_balloon_icon', WORD_BALLOON_URI . 'css/word_balloon_icon.min.css',array(),WORD_BALLOON_VERSION);
		}



		
		wp_enqueue_script('word_balloon_base_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_base.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);

		
		wp_enqueue_script('word_balloon_balloon_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_balloon.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);

		
		wp_enqueue_script('word_balloon_avatar_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_avatar.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);

		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if(is_plugin_active( 'word-balloon-pro/word-balloon-pro.php' )):
			
			wp_enqueue_script('word_balloon_favorite_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_favorite.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);
		endif;

		
		wp_enqueue_script('word_balloon_restore_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_restore.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);

		
		wp_enqueue_script('word_balloon_post_script', WORD_BALLOON_URI . 'js/word_balloon_post.min.js',array('word_balloon_balloon_custom_script'),WORD_BALLOON_VERSION,true);





		wp_enqueue_style('word_balloon_admin', WORD_BALLOON_URI . 'css/word_balloon_admin.min.css',array('word_balloon_user_style'),WORD_BALLOON_VERSION);
		wp_enqueue_style('word_balloon_post', WORD_BALLOON_URI . 'css/word_balloon_post.min.css',array('word_balloon_admin'),WORD_BALLOON_VERSION);
		wp_enqueue_style('word_balloon_font', WORD_BALLOON_URI . 'css/font/style.min.css',array(),WORD_BALLOON_VERSION);

		
		$translations = word_balloon_scriput_translations();
		wp_localize_script( 'word_balloon_post_script', 'translations', $translations );

		
		add_editor_style( WORD_BALLOON_URI . 'css/word_balloon_user.min.css');
		

		require_once WORD_BALLOON_DIR . 'inc/admin-post.php';
		add_action('admin_footer', 'word_balloon_post_page');

		word_balloon_user_styles();









		if($load_setting['enable_sound'] === 'true')
			wp_enqueue_script( 'word_balloon_action_sound_script', WORD_BALLOON_URI . 'js/action/word_balloon_action_sound.min.js', array(), WORD_BALLOON_VERSION,true );

		add_action( 'admin_print_footer_scripts' , 'word_balloon_custom_edit_style' , 100);

		if( get_bloginfo('version') < 4.9){
			add_action( 'admin_print_footer_scripts', 'word_balloon_old_wp' , 99999 );
		}
	}
}
add_action( 'admin_enqueue_scripts', 'word_balloon_custom_enqueue' );

// TinyMCEにボタン追加
function word_balloon_tinymce_button() {
	if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) ) {
		add_filter( 'mce_buttons', 'word_balloon_register_tinymce_button' );
		add_filter( 'mce_external_plugins', 'word_balloon_tinymce_button_script' );
	}
}
add_action( 'admin_init', 'word_balloon_tinymce_button' );


function word_balloon_register_tinymce_button( $buttons ) {
	array_push( $buttons, 'word_balloon_button' );
	array_push( $buttons, 'word_balloon_restore_button' );
	return $buttons;
}


function word_balloon_tinymce_button_script( $plugin_array ) {
	$plugin_array['word_balloon_script'] = WORD_BALLOON_URI . 'js/word_balloon_tinymce.min.js';
	return $plugin_array;
}


function custom_add_quicktags() {
	if (wp_script_is('quicktags')){
		?>
		<script>
			function word_balloon_callback() { jQuery('#w_b_modal_open').click(); }
			QTags.addButton( 'word_balloon', '<?php echo esc_html_x('Word Balloon','text_button','word-balloon'); ?>', word_balloon_callback );
			function word_balloon_restore_callback() { jQuery('#w_b_restore_copy').click(); }
			QTags.addButton( 'word_balloon_restore', '<?php echo esc_html_x('Restore Balloon','text_button','word-balloon'); ?>', word_balloon_restore_callback );
		</script>
		<?php
	}
}
add_action( 'admin_print_footer_scripts', 'custom_add_quicktags' );

function word_balloon_custom_edit_style(){
	echo '<style type="text/css" id="w_b_css"></style>';
}

function word_balloon_scriput_translations() {
	return array(
		'select_an_avatar' => __( 'Select an avatar', 'word-balloon' ),
		'select' => __( 'Select', 'word-balloon' ),
		'select_a_photo' => __( 'Select a photo', 'word-balloon' ),
		'do_you_want_to_delete' => __( 'Do you want to delete the avatar?', 'word-balloon' ),
		'really_remove_avatar' => __( 'Really remove avatar from the system?', 'word-balloon' ),
		'edit_avatar' => __( 'Edit Avatar', 'word-balloon' ),
		'edit_avatar_name' => __( 'Name', 'word-balloon' ),
		'edit_avatar_note' => __( 'Note', 'word-balloon' ),
		'edit_avatar_update' => __( 'Update', 'word-balloon' ),
		'edit_avatar_cancel' => __( 'Cancel', 'word-balloon' ),
		'edit_avatar_priority' => __( 'Priority', 'word-balloon' ),
		'anonymous' => __( 'John Doe', 'word-balloon' ),
		'select_wallpaper' => __( 'Select a wallpaper', 'word-balloon' ),
		'select_a_sound' => __( 'Select a sound', 'word-balloon' ),
		'dialog_wallpaper' => __( 'Wallpaper', 'word-balloon' ),
		'dialog_side_by_side' => __( 'Side by side box', 'word-balloon' ),
		'dialog_restore' => __( 'Restore', 'word-balloon' ),
	);
}




add_action( 'enqueue_block_editor_assets', 'word_balloon_user_styles' );




function word_balloon_extend_tiny_mce_before_init( $mce_init ) {
	$mce_init['cache_suffix'] = 'v='.time();
	return $mce_init;
}
add_filter( 'tiny_mce_before_init', 'word_balloon_extend_tiny_mce_before_init' );




if ( ! function_exists( 'word_balloon_pro_plugin_action_links' ) ) :
	function word_balloon_plugin_action_links($links, $file) {
		if ('word-balloon/word-balloon.php' == $file  && current_user_can( 'manage_options' )) {
			$settings_link = '<a href="' . admin_url( 'options-general.php?page=word-balloon' ) . '">'.__( 'Settings', 'word-balloon' ).'</a>';
			array_unshift($links, $settings_link);
		}
		return $links;
	}
	add_filter('plugin_action_links', 'word_balloon_plugin_action_links', 10, 2);
endif;

function word_balloon_old_wp() {
	echo '<style type="text/css" id="w_b_old_css">#w_b_overlay .wp-color-result {
		-webkit-box-sizing: content-box;
		-moz-box-sizing: content-box;
		-o-box-sizing: content-box;
		-ms-box-sizing: content-box;
		box-sizing: content-box;
	}</style>';

}


function word_balloon_update_check() {

	if ( get_site_option( 'word_balloon_version' ) != WORD_BALLOON_VERSION ) {
		update_option( 'word_balloon_version', WORD_BALLOON_VERSION );

		
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		if(is_plugin_active( 'word-balloon-pro/word-balloon-pro.php' )){
			if (defined("WORD_BALLOON_PRO_DIR")) {
				require_once WORD_BALLOON_PRO_DIR . 'inc/build_style.php';
				if ( function_exists( 'word_balloon_pro_build_css_file' ) ){
					word_balloon_pro_build_css_file();
					return;
				}
				
				if ( function_exists( 'word_balloon_build_css_file' ) ){
					word_balloon_build_css_file();
				}
			}
		}

	}
}
add_action( 'plugins_loaded', 'word_balloon_update_check' );
